#ifndef NT2_INCLUDE_CONSTANTS_EULER_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_EULER_HPP_INCLUDED

#include <nt2/exponential/include/constants/euler.hpp>

#endif
